<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Reference Documentation

- **[changelog-standards.md](changelog-standards.md)** — writing CHANGELOG.md entries manually, understanding the changelog sync marker system, deciding how to format a changelog entry
- **[claude-cli-stream-json.md](claude-cli-stream-json.md)** — parsing claude cli output, extracting metadata from stream-json, working with session_id, implementing stream-json parser
- **[cli-flag-patterns.md](cli-flag-patterns.md)** — designing CLI flag requirements, implementing conditional flag requirements, documenting flag combinations
- **[gastown-analysis.md](gastown-analysis.md)** — learning from parallel agent orchestration systems, designing multi-agent coordination, understanding propulsion-based agent patterns, comparing erk to other agentic systems
- **[git-diff-syntax.md](git-diff-syntax.md)** — writing git diff commands, comparing branches with git, understanding three-dot vs two-dot git syntax
- **[github-actions-api.md](github-actions-api.md)** — triggering GitHub Actions workflows from erk code, querying workflow run status from gateway methods, debugging workflow run discovery or correlation, choosing between REST and GraphQL for workflow queries, working with GitHub Actions API, writing GitHub Actions YAML workflows, configuring workflow triggers
- **[interactive-claude-config.md](interactive-claude-config.md)** — implementing erk commands that launch Claude or Codex interactively, understanding the two dangerous flags and when to use each, working with the with_overrides() None-preservation pattern, configuring agent permission modes across config and CLI layers
- **[llm-json-parsing.md](llm-json-parsing.md)** — parsing JSON from LLM text output, extracting structured data from Claude responses, writing code that processes LLM-generated JSON
- **[objective-summary-format.md](objective-summary-format.md)** — working with objective-plan command or objective-view command, modifying how objective context flows between agents, changing roadmap status inference logic, parsing objective summary JSON output
- **[toml-handling.md](toml-handling.md)** — reading TOML files, writing TOML files, generating TOML configuration, working with config.toml, working with pyproject.toml
